==> nextcloud-22.2.9.tgz: nextcloud/apps/dashboard/l10n/sc.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Pannellu de controllu",
    "Dashboard app" : "Aplicatzione de su pannellu de controllu",
    "Customize" : "Personaliza",
    "Edit widgets" : "Modìfica ordìngios",
    "Get more widgets from the App Store" : "Otene àteros trastos dae sa butega de is aplicatziones",
    "Change background image" : "Càmbia immàgine de isfundu",
    "Weather service" : "Servìtziu de su tempus",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Pro sa riservadesa tua, su serbidore Nextcloud rechedet is datos de su tempus pro tene, duncas su servìtziu de su tempus no retzit informatziones personales.",
    "Weather data from Met.no" : "Datos de su tempus dae Met.no",
    "geocoding with Nominatim" : "geocodìfica cun Nominatim",
    "elevation data from OpenTopoData" : "datos de elevada dae OpenTopoData",
    "Weather" : "Tempus",
    "Status" : "Istadu",
    "Good morning" : "Bona die",
    "Good morning, {name}" : "Bona die, {name}",
    "Good afternoon" : "Salude",
    "Good afternoon, {name}" : "Salude, {name}",
    "Good evening" : "Salude",
    "Good evening, {name}" : "Salude, {name}",
    "Hello" : "Salude",
    "Hello, {name}" : "Salude, {name}",
    "Pick from Files" : "Sèbera dae archìvios",
    "Default images" : "Imàgines predefinidas",
    "Plain background" : "Isfundu simpre",
    "Insert from {productName}" : "Inserta dae {productName}",
    "Show something" : "Mustra calicuna cosa"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.9.tgz: nextcloud/apps/dashboard/l10n/sc.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Pannellu de controllu",
    "Dashboard app" : "Aplicatzione de su pannellu de controllu",
    "Customize" : "Personaliza",
    "Edit widgets" : "Modìfica ordìngios",
    "Get more widgets from the App Store" : "Otene àteros trastos dae sa butega de is aplicatziones",
    "Change background image" : "Càmbia immàgine de isfundu",
    "Weather service" : "Servìtziu de su tempus",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Pro sa riservadesa tua, su serbidore Nextcloud rechedet is datos de su tempus pro tene, duncas su servìtziu de su tempus no retzit informatziones personales.",
    "Weather data from Met.no" : "Datos de su tempus dae Met.no",
    "geocoding with Nominatim" : "geocodìfica cun Nominatim",
    "elevation data from OpenTopoData" : "datos de elevada dae OpenTopoData",
    "Weather" : "Tempus",
    "Status" : "Istadu",
    "Good morning" : "Bona die",
    "Good morning, {name}" : "Bona die, {name}",
    "Good afternoon" : "Salude",
    "Good afternoon, {name}" : "Salude, {name}",
    "Good evening" : "Salude",
    "Good evening, {name}" : "Salude, {name}",
    "Hello" : "Salude",
    "Hello, {name}" : "Salude, {name}",
    "Pick from Files" : "Sèbera dae archìvios",
    "Plain background" : "Isfundu simpre",
    "Insert from {productName}" : "Inserta dae {productName}",
    "Show something" : "Mustra calicuna cosa",
    "Default images" : "Imàgines predefinidas"
},
"nplurals=2; plural=(n != 1);");
